import YAML from "yaml";
import { FileError, FileNotFoundError } from "./errors";

export async function loadFileOrFail(filePath: string): Promise<string> {
  const fileToLoad = Bun.file(filePath);
  const fileExists = await fileToLoad.exists();

  if (!fileExists) {
    throw new FileNotFoundError(`File not found: ${filePath}`);
  }

  return await fileToLoad.text();
}

export async function loadYAMLFileOrFail(filePath: string): Promise<unknown> {
  try {
    return YAML.parse(await loadFileOrFail(filePath));
  } catch (error) {
    throw new FileError("Failed to parse YAML file", filePath, `${error}`);
  }
}
